@@ -1,10 +1,6 @@
 package File::LibMagic;
-{
-  $File::LibMagic::VERSION = '0.99';
-}
-BEGIN {
-  $File::LibMagic::AUTHORITY = 'cpan:DROLSKY';
-}
+# git description: v1.02-6-g41e5fce
+$File::LibMagic::VERSION = '1.03';
 
 use 5.008;
 
@@ -70,70 +66,56 @@ $EXPORT_TAGS{"all"}
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-use constant _MAGIC_FILE      => 0;
-use constant _MIME_HANDLE     => 1;
-use constant _DESCRIBE_HANDLE => 2;
-
 sub new {
     my ( $class, $magic_file ) = @_;
+    return bless { magic_file => $magic_file }, $class;
+}
 
-    return bless [ $magic_file || q{} ], $class;
+sub checktype_contents {
+    my ( $self, $data ) = @_;
+    return magic_buffer( $self->_mime_handle(), $data );
+}
+
+sub checktype_filename {
+    my ( $self, $filename ) = @_;
+    return magic_file( $self->_mime_handle(), $filename );
+}
+
+sub describe_contents {
+    my ( $self, $data ) = @_;
+    return magic_buffer( $self->_describe_handle(), $data );
+}
+
+sub describe_filename {
+    my ( $self, $filename ) = @_;
+    return magic_file( $self->_describe_handle(), $filename );
 }
 
 sub _mime_handle {
     my ($self) = @_;
 
-    my $m = magic_open( MAGIC_MIME() );
-    magic_load( $m, $self->[_MAGIC_FILE] );
-
-    return $m;
+    return $self->{mime_handle} ||= do {
+        my $m = magic_open( MAGIC_MIME() );
+        magic_load( $m, $self->{magic_file} );
+        $m;
+    };
 }
 
-sub _descr_handle {
+sub _describe_handle {
     my ($self) = @_;
 
-    my $m = magic_open( MAGIC_NONE() );
-    magic_load( $m, $self->[_MAGIC_FILE] );
-
-    return $m;
-}
-
-sub checktype_contents {
-    my ( $self, $data ) = @_;
-
-    my $m = $self->[_MIME_HANDLE] ||= $self->_mime_handle();
-    return magic_buffer( $m, $data );
-}
-
-sub checktype_filename {
-    my ( $self, $filename ) = @_;
-
-    my $m = $self->[_MIME_HANDLE] ||= $self->_mime_handle();
-
-    return magic_file( $m, $filename );
-}
-
-sub describe_contents {
-    my ( $self, $data ) = @_;
-
-    my $m = $self->[_DESCRIBE_HANDLE] ||= $self->_descr_handle();
-
-    return magic_buffer( $m, $data );
-}
-
-sub describe_filename {
-    my ( $self, $filename ) = @_;
-
-    my $m = $self->[_DESCRIBE_HANDLE] ||= $self->_descr_handle();
-
-    return magic_file( $m, $filename );
+    return $self->{describe_handle} ||= do {
+        my $m = magic_open( MAGIC_NONE() );
+        magic_load( $m, $self->{magic_file} );
+        $m;
+    };
 }
 
 sub DESTROY {
     my ($self) = @_;
 
-    for ( _MIME_HANDLE, _DESCRIBE_HANDLE ) {
-        magic_close( $self->[$_] ) if $self->[$_];
+    for my $key (qw( mime_handle describe_handle )) {
+        magic_close( $self->{$key} ) if defined $self->{$key};
     }
 }
 
@@ -145,13 +127,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 File::LibMagic - Determine MIME types of data or files using libmagic
 
 =head1 VERSION
 
-version 0.99
+version 1.03
 
 =head1 SYNOPSIS
 
@@ -169,8 +153,30 @@ version 0.99
 
 =head1 DESCRIPTION
 
-The C<File::LibMagic> is a simple perl interface to libmagic from
-the file package (version 4.x or 5.x).
+The C<File::LibMagic> is a simple perl interface to libmagic from the file
+package (version 4.x or 5.x). You will need both the library (F<libmagic.so>)
+and the header file (F<magic.h>) to build this Perl module.
+
+=head2 Installing libmagic
+
+On Debian/Ubuntu run:
+
+    sudo apt-get install libmagic-dev
+
+On Mac you can use homebrew (http://brew.sh/):
+
+    brew install libmagic
+
+=head2 Specifying lib and/or include directories
+
+On some systems, you may need to pass additional lib and include directories
+to the Makefile.PL. You can do this with the `--lib` and `--include`
+parameters:
+
+    perl Makefile.PL --lib /usr/local/include --include /usr/local/include
+
+You can pass these parameters multiple times to specify more than one
+location.
 
 =head1 API
 
@@ -196,7 +202,8 @@ magic files at all.
 
 =head2 $magic->checktype_contents($data)
 
-Returns the MIME type of the data given as the first argument.
+Returns the MIME type of the data given as the first argument. The data can be
+passed as a plain scalar or as a reference to a scalar.
 
 This is the same value as would be returned by the C<file> command with the
 C<-i> switch.
@@ -211,6 +218,7 @@ C<-i> switch.
 =head2 $magic->describe_contents($data)
 
 Returns a description (as a string) of the data given as the first argument.
+The data can be passed as a plain scalar or as a reference to a scalar.
 
 This is the same value as would be returned by the C<file> command with no
 switches.
@@ -254,7 +262,7 @@ Returns the description of a file, just like the C<describe_filename> method.
 
 This interface is exported by:
 
-  use File::LibMagic ':easy';
+  use File::LibMagic ':complete';
 
 This interface exports several subroutines:
 
@@ -292,7 +300,7 @@ Closes the magic handle.
 
 =head1 EXCEPTIONS
 
-This module can throw an exception if you system runs out of memory when
+This module can throw an exception if your system runs out of memory when
 trying to call C<magic_open> internally.
 
 =head1 SUPPORT
@@ -347,7 +355,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Andreas Fitzner, Michael Hendricks, and Dave Rolsky.
+This software is copyright (c) 2014 by Andreas Fitzner, Michael Hendricks, and Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
